AcpsAcpsReaderSocket class

Inheritance

Constructors

AcpsAcpsReaderSocket({required ArtemisAcpsController controller, required ReaderDeviceType readerType, bool syncStatusToController = false})

Properties

al String
getter/setter pair
bpCommandKeysAea List<String>
no setter
bpCommandKeysDirect List<String>
no setter
connectedAddress String?
no setter
controller ArtemisAcpsController
final
devId String?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
img String
no setter
inProgressAeaActions Map<String, ArtemisAcpsBroadcastData>
getter/setter pair
inProgressDirectActions Map<String, ArtemisAcpsDirectCommand>
getter/setter pair
kioskSetting List<ArtemisKioskSettingRow>
getter/setter pair
readerType ReaderDeviceType
final
retriedTransactions List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status → HubConnectionState
no setter
syncStatusToController bool
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
aeaResponse(List<Object?>? arguments) → void
broadcastData(String data) → dynamic
completeTransaction(ArtemisAcpsAeaResponse response) → dynamic
connect(ArtemisAcpsDeviceConfig config) Future<bool>
disconnect() Future<void>
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
generateTransactionID() String
getIcons({required double size}) Widget
handleError(String error) → void
handShake() Future<void>
initDevices() Future<bool>
invokeAeaPRCommand(PrCommand command) → void
invokeBroadcast(ArtemisAcpsBroadcastData data, {String? overrideTransactionID}) Future<ArtemisAcpsAeaResponse>
kioskRefresh(ArtemisAcpsKiosk? kiosk) → void
kioskStatusRefresh(ArtemisAcpsKioskStatus kioskStatus) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onArtemisAcpsKioskStatusChange(List<Object?>? arguments) → void
onVirtualDeviceRequest(List<Object?>? arguments) → void
reconnect() Future<void>
refreshSocketStatus(HubConnectionState? status) → void
removeAcps() → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setKioskSetting(List<ArtemisKioskSettingRow> settings) → void
toString() String
A string representation of this object.
inherited
updateReceivedData(ArtemisAcpsReceivedData receivedData) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited