menu
artemis_acps package
documentation
classes/artemis_acps_aea_command_class.dart
PrCommand class
PrCommand class
dark_mode
light_mode
PrCommand
class
Constructors
PrCommand
({
required
String
deviceId
,
required
String
data
,
String
?
printerId
})
PrCommand.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
data
→
String
final
deviceId
→
String
final
hashCode
→
int
The hash code for this object.
no setter
inherited
printerId
→
String
?
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
deviceId
,
String
?
data
,
String
?
printerId
})
→
PrCommand
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
artemis_acps package
documentation
classes/artemis_acps_aea_command_class
PrCommand class
artemis_acps_aea_command_class library