ArtemisAcpsBroadcastData class

Constructors

ArtemisAcpsBroadcastData({required String deviceId, required String? workstationToken, String? transactionId, String? message, String? deviceType, String? messageType})
ArtemisAcpsBroadcastData.fromJson(Map<String, dynamic> json)
factory

Properties

deviceId String
final
deviceType String?
final
devId String
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
final
messageType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String?
final
workstationToken String?
final

Methods

copyWith({String? deviceId, String? workstationToken, String? transactionId, String? message, String? messageType, String? deviceType}) ArtemisAcpsBroadcastData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited