AcpsKioskUtil class
Constructors
- AcpsKioskUtil({required ArtemisAcpsController controller})
Properties
- al ↔ String
-
getter/setter pair
-
bpCommandKeysAea
→ List<
String> -
no setter
-
bpCommandKeysDirect
→ List<
String> -
no setter
-
btCommandKeysAea
→ List<
String> -
no setter
-
btCommandKeysDirect
→ List<
String> -
no setter
- connectedAddress → String?
-
no setter
- controller → ArtemisAcpsController
-
final
- devId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inProgressAeaActions
↔ Map<
String, ArtemisAcpsAeaCommand> -
getter/setter pair
-
inProgressDirectActions
↔ Map<
String, ArtemisAcpsDirectCommand> -
getter/setter pair
-
kioskSetting
↔ List<
ArtemisKioskSettingRow> -
getter/setter pair
-
retriedTransactions
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aeaDirectResponse(
List< Object?> ? arguments) → Future<void> -
aeaResponse(
List< Object?> ? arguments) → void -
completeTransaction(
ArtemisAcpsAeaResponse response) → dynamic -
connect(
ArtemisAcpsKioskConfig config) → Future< bool> -
disconnect(
) → Future< void> -
generateTransactionID(
) → String -
getKioskSetting(
ArtemisAcpsKioskConfig config) → Future< List< ArtemisKioskSettingRow> ?> -
handleError(
String error) → void -
initDevices(
) → Future< bool> -
invokeAeaCommand(
ArtemisAcpsAeaCommand command, {String? overrideTransactionID}) → Future< ArtemisAcpsAeaResponse> -
invokeAeaPRCommand(
PrCommand command) → void -
invokeDirectCommand(
ArtemisAcpsDirectCommand command, {String? overrideTransactionID}) → Future< ArtemisAcpsAeaResponse> -
kioskRefresh(
ArtemisAcpsKiosk? kiosk) → void -
kioskStatusRefresh(
ArtemisAcpsKioskStatus kioskStatus) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onArtemisAcpsKioskStatusChange(
List< Object?> ? arguments) → void -
onDevicesStatusChanged(
List< Object?> ? arguments) → void -
onReaderData(
List< Object?> ? arguments) → void -
reconnect(
) → Future< void> -
refreshSocketStatus(
HubConnectionState? status) → dynamic -
removeAcps(
) → dynamic -
setKioskSetting(
List< ArtemisKioskSettingRow> settings) → void -
subscribe(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
updateReceivedData(
ArtemisAcpsReceivedData receivedData) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited