ArtemisAcpsDeviceConfig class
Constructors
- ArtemisAcpsDeviceConfig({required String deviceId, required ReaderDeviceType? deviceType, required String workstationToken, int timeout = 10, required String version, required String os})
-
ArtemisAcpsDeviceConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deviceId → String
-
final
- deviceType → ReaderDeviceType?
-
final
- devId → String
-
no setter
- getUrl → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- os → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → int
-
final
- version → String
-
final
- workstationToken → String
-
final
Methods
-
copyWith(
{String? deviceId, ReaderDeviceType? deviceType, String? workstationToken, int? timeout, String? version, String? os}) → ArtemisAcpsDeviceConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited